
picutils
--------

|PyPI version|

json2df is a library does batch processing pictures
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

github: https://github.com/shichaoji/picutils
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

-  If you would like to run a image hosting website, it is handy to
   process a large number of images

I have used the library processed almost 1 million photos for my other project face similarity searching & indexing, landmark detecting
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

http://iridescent.date/
^^^^^^^^^^^^^^^^^^^^^^^

.. |PyPI version| image:: https://badge.fury.io/py/picutils.svg
   :target: https://badge.fury.io/py/picutils

installation
~~~~~~~~~~~~
.. code:: shell
pip install pictutils

usage example
~~~~~~~~~~~~~

Batch reducing pics size to about 200kb each, if you have many HD pics saved in a folder, run the library will batch coverting pics in the folder to .jpg and then resizing all pics till 100-200 kb each.R
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

-  Run $ python -m picutils.process\_pics , and then pass the images
   folder's name, in the directory where that folder resides

.. image:: https://user-images.githubusercontent.com/20619704/34473164-3901bc16-ef3d-11e7-9f78-6c62fd4b3f15.jpg
   :alt: Demo 1
   :align: left

````


Making index.html webbrowser file for a folder of pics for overall viewing, or hosting in a webpage
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

-  Run $ python -m picutils.html\_index , and then pass the images
   folder's name, in the directory where that folder resides

   -  the program will make a sub-thumbnail folder, so even if image
      sizes in the folder are very large, the small view pics in the
      index html will load instantly, for the purpose of hosting picture
      website when visitors has slow internet
   -  Thanks to myphotopack.com for those pretty pictures

.. image:: https://user-images.githubusercontent.com/20619704/34473402-1d233422-ef40-11e7-9bb2-ab373c5a6377.jpg
   :width: 80%
   :alt: Demo 2
   :align: left

````
   
   
Making a viewer.html webbrowser file for a folder of pics for single viewing, e.g. hosting a manga Website
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

-  Run $ python -m picutils.html\_viewer , and then pass the images
   folder's name, in the directory where that folder resides

   -  click right side of the photo will view next, while clicking left
      side turns to previous photo

.. image:: https://user-images.githubusercontent.com/20619704/34473527-e93fd4ce-ef41-11e7-94b9-85873cd9219e.jpg
   :width: 80%
   :alt: Demo 3
   :align: left